'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _set2 = require('lodash/set');

var _set3 = _interopRequireDefault(_set2);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _redux = require('redux');

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var START = _constants.actionTypes.START,
    SET = _constants.actionTypes.SET,
    SET_ORDERED = _constants.actionTypes.SET_ORDERED,
    SET_PROFILE = _constants.actionTypes.SET_PROFILE,
    LOGIN = _constants.actionTypes.LOGIN,
    LOGOUT = _constants.actionTypes.LOGOUT,
    LOGIN_ERROR = _constants.actionTypes.LOGIN_ERROR,
    NO_VALUE = _constants.actionTypes.NO_VALUE,
    AUTHENTICATION_INIT_STARTED = _constants.actionTypes.AUTHENTICATION_INIT_STARTED,
    AUTHENTICATION_INIT_FINISHED = _constants.actionTypes.AUTHENTICATION_INIT_FINISHED,
    UNAUTHORIZED_ERROR = _constants.actionTypes.UNAUTHORIZED_ERROR,
    AUTH_UPDATE_SUCCESS = _constants.actionTypes.AUTH_UPDATE_SUCCESS;


var pathToArr = function pathToArr(path) {
  return path ? path.split(/\//).filter(function (p) {
    return !!p;
  }) : [];
};

var requestingReducer = function requestingReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments[1];
  var path = action.path,
      requesting = action.requesting;

  switch (action.type) {
    case START:
    case SET:
      return _extends({}, state, _defineProperty({}, pathToArr(path).join('/'), requesting));

    default:
      return state;
  }
};

var getPathStr = function getPathStr(path) {
  return path ? path.replace('/', '.') : '';
};

var dataReducer = function dataReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments[1];
  var path = action.path,
      data = action.data,
      ordered = action.ordered;

  switch (action.type) {
    case SET:
      return _extends({}, state, (0, _set3.default)({}, getPathStr(path), data));
    case SET_ORDERED:
      return _extends({}, state, (0, _set3.default)({}, getPathStr(path), ordered));
    case NO_VALUE:
      return _extends({}, state, (0, _set3.default)({}, getPathStr(path), {}));
    default:
      return state;
  }
};

var authReducer = function authReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments[1];

  switch (action.type) {
    case LOGIN:
    case AUTH_UPDATE_SUCCESS:
      return action.auth || undefined;
    case LOGOUT:
    case LOGIN_ERROR:
      return null;
    default:
      return state;
  }
};

var profileReducer = function profileReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  var action = arguments[1];

  switch (action.type) {
    case SET_PROFILE:
      return _extends({}, state, action.profile);
    case LOGOUT:
    case LOGIN_ERROR:
      return null;
    default:
      return state;
  }
};

var isInitializingReducer = function isInitializingReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  var action = arguments[1];

  switch (action.type) {
    case AUTHENTICATION_INIT_STARTED:
      return true;
    case AUTHENTICATION_INIT_FINISHED:
      return false;
    default:
      return state;
  }
};

var errorsReducer = function errorsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var action = arguments[1];

  switch (action.type) {
    case UNAUTHORIZED_ERROR:
      return [].concat(_toConsumableArray(state), [action.payload]);
    case LOGOUT:
      return null;
    default:
      return state;
  }
};

exports.default = (0, _redux.combineReducers)({
  requesting: requestingReducer,
  data: dataReducer,
  auth: authReducer,
  profile: profileReducer,
  isInitializing: isInitializingReducer,
  errors: errorsReducer
});
module.exports = exports['default'];